@@ -2,6 +2,9 @@ from ._python_calamine import (
     CalamineError,
     CalamineSheet,
     CalamineWorkbook,
+    SheetMetadata,
+    SheetTypeEnum,
+    SheetVisibleEnum,
     load_workbook,
 )
 
@@ -9,5 +12,8 @@ __all__ = (
     "CalamineError",
     "CalamineSheet",
     "CalamineWorkbook",
+    "SheetMetadata",
+    "SheetTypeEnum",
+    "SheetVisibleEnum",
     "load_workbook",
 )
