@@ -1,8 +1,10 @@
 use std::fmt::Display;
+use std::sync::Arc;
 
 use calamine::{DataType, Range, SheetType, SheetVisible};
 use pyo3::class::basic::CompareOp;
 use pyo3::prelude::*;
+use pyo3::types::PyList;
 
 use crate::CellValue;
 
@@ -117,12 +119,15 @@ impl SheetMetadata {
 pub struct CalamineSheet {
     #[pyo3(get)]
     name: String,
-    range: Range<DataType>,
+    range: Arc<Range<DataType>>,
 }
 
 impl CalamineSheet {
     pub fn new(name: String, range: Range<DataType>) -> Self {
-        CalamineSheet { name, range }
+        CalamineSheet {
+            name,
+            range: Arc::new(range),
+        }
     }
 }
 
@@ -164,33 +169,34 @@ impl CalamineSheet {
 
     #[pyo3(signature = (skip_empty_area=true, nrows=None))]
     fn to_python(
-        &self,
+        slf: PyRef<'_, Self>,
         skip_empty_area: bool,
         nrows: Option<u32>,
-    ) -> PyResult<Vec<Vec<CellValue>>> {
-        let mut range = self.range.to_owned();
+    ) -> PyResult<&PyList> {
+        let nrows = match nrows {
+            Some(nrows) => nrows,
+            None => slf.range.end().map_or(0, |end| end.0 + 1),
+        };
 
-        if !skip_empty_area {
-            if let Some(end) = range.end() {
-                range = range.range((0, 0), end)
-            }
-        }
+        let range = if skip_empty_area || Some((0, 0)) == slf.range.start() {
+            Arc::clone(&slf.range)
+        } else if let Some(end) = slf.range.end() {
+            Arc::new(slf.range.range(
+                (0, 0),
+                (if nrows > end.0 { end.0 } else { nrows - 1 }, end.1),
+            ))
+        } else {
+            Arc::clone(&slf.range)
+        };
 
-        if let Some(nrows) = nrows {
-            if range.end().is_some() && range.start().is_some() {
-                range = range.range(
-                    range.start().unwrap(),
-                    (
-                        range.start().unwrap().0 + (nrows - 1),
-                        range.end().unwrap().1,
-                    ),
+        Ok(PyList::new(
+            slf.py(),
+            range.rows().take(nrows as usize).map(|row| {
+                PyList::new(
+                    slf.py(),
+                    row.iter().map(<&DataType as Into<CellValue>>::into),
                 )
-            }
-        }
-
-        Ok(range
-            .rows()
-            .map(|row| row.iter().map(|x| x.into()).collect())
-            .collect())
+            }),
+        ))
     }
 }
